@@ -697,7 +697,11 @@ class GVoiceBackend(object):
 			message = Message()
 			message.body = messageParts
 			message.whoFrom = conv.name
-			message.when = conv.time.strftime("%I:%M %p")
+			try:
+				message.when = conv.time.strftime("%I:%M %p")
+			except ValueError:
+				_moduleLogger.exception("Confusing time provided: %r" % conv.time)
+				message.when = "Unknown"
 			conv.messages = (message, )
 
 			yield conv
@@ -896,9 +900,9 @@ def validate_response(response):
 	Validates that the JSON response is A-OK
 	"""
 	try:
-		assert response is not None
-		assert 'ok' in response
-		assert response['ok']
+		assert response is not None, "Response not provided"
+		assert 'ok' in response, "Response lacks status"
+		assert response['ok'], "Response not good"
 	except AssertionError:
 		raise RuntimeError('There was a problem with GV: %s' % response)
 
